#!/usr/bin/env bash

set -ex

export HOME=/root

# Generate a machine ID
dbus-uuidgen > /var/lib/dbus/machine-id

# Create fstab
echo "# /etc/fstab: static file system information." | tee /etc/fstab
echo "# <file system> <mount point> <type> <options> <dump> <pass>" | tee -a /etc/fstab

ROOTDEV="$(df --output=source / | sed 1d)"
ROOTUUID="$(blkid -o value -s UUID "${ROOTDEV}")"
echo "# / was on ${ROOTDEV} during installation" | tee -a /etc/fstab
echo "UUID=${ROOTUUID} / ext4 errors=remount-ro 0 1" | tee -a /etc/fstab

if [ -d /boot/efi/ ]
then
    EFIDEV="$(df --output=source /boot/efi/ | sed 1d)"
    if [ "${EFIDEV}" != "${ROOTDEV}" ]
    then
        EFIUUID="$(blkid -o value -s UUID "${EFIDEV}")"
        echo "# /boot/efi was on ${EFIDEV} during installation" | tee -a /etc/fstab
        echo "UUID=${EFIUUID} /boot/efi vfat umask=0077 0 1" | tee -a /etc/fstab
    fi
fi

# Remove installer packages
dnf --assumeyes remove distinst

# Install grub packages
dnf --assumeyes install "$@"

# Configure the right grub2.cfg

GRUB2_CFG_FILES="/etc/grub2-efi.cfg /etc/grub2.cfg"

for grub2cfg in ${GRUB2_CFG_FILES}; do
    if [[ -L ${grub2cfg} ]] && [[ -a ${grub2cfg} ]]; then
        grub2-mkconfig -o ${grub2cfg}
    fi
done
